@@ -10,7 +10,8 @@ use utf8;
 
 {
 
-  package My::Collision;
+  package #hide
+  My::Collision;
   use base qw(My);
 
   use constant TABLE   => 'collision';
@@ -27,7 +28,8 @@ use utf8;
 
 {
 
-  package My::SiteUser;
+  package #hide
+  My::SiteUser;
   use base qw(My::User);
   my $_CHECKS = My::User->CHECKS;
   $_CHECKS->{group_id}{default} = 3;
